:root {
    /* Jupyter Lab Integration (Light Theme) */
    --jp-content-font-color1: var(--txbk-content-color);
    --jp-content-font-family: var(--txbk-content-font-family);
    --jp-content-line-height: var(--txbk-content-line-height);
    --jp-content-link-color: var(--link-color);
    --jp-content-font-size: var(--txbk-content-font-size);

    --jp-code-font-size: var(--txbk-ui-mono-font-size);
    --jp-code-line-height: var(--txbk-ui-mono-line-height);
    --jp-code-padding: 5px;
    --jp-code-font-family-default: var(--txbk-code-font-family);
    --jp-code-font-family: var(--jp-code-font-family-default);
    --jp-code-presentation-font-size: var(--txbk-ui-mono-font-size);
    --jp-content-heading-font-weight: 500;
    --jp-content-heading-line-height: 1;

    --jp-cell-prompt-font-family: var(--txbk-code-font-family);

    --jp-layout-color0: var(--code-background-color);
    --jp-cell-prompt-not-active-font-color: #aba9a9;
}

/* body class*/

body.jp-Notebook {

    background-color: var(--background-color) !important;
    font-weight: 300;
    font-family: var(--txbk-ui-font-family);
    color: var(--txbk-ui-color);
    overflow: inherit;
    vertical-align: middle;
    font-size: var(--txbk-ui-font-size);
}


/* MARKDOWN CELLS DISPLAY MODE */

div.jp-RenderedHTMLCommon {
    font-family: var(--txbk-content-font-family) !important;
    font-size: var(--txbk-content-font-size) !important;
    color: var(--txbk-content-color) !important;
    font-kerning: auto;
    text-align: justify !important;
    display: block;
    word-break: normal !important;
    word-wrap: break-word !important;
}

div.jp-RenderedHTMLCommon a {
    color: var(--link-color) !important;
}

div.jp-RenderedHTMLCommon h1,
div.jp-RenderedHTMLCommon h2,
div.jp-RenderedHTMLCommon h3,
div.jp-RenderedHTMLCommon h4,
div.jp-RenderedHTMLCommon h5,
div.jp-RenderedHTMLCommon h6 {
    font-family:  var(--txbk-content-font-family) !important;
    font-style: normal !important;
}

/* Font-sizes for headers */
div.jp-RenderedHTMLCommon h1 {
    font-size: 4.2rem !important;
    text-align: center !important;
    padding-top:  3rem;
    padding-bottom: 3rem;
}

div.jp-RenderedHTMLCommon h2 {
    font-size: 3.8rem !important;
}

div.jp-RenderedHTMLCommon h3 {
    font-size: 3.4rem !important;
}

div.jp-RenderedHTMLCommon h4 {
    font-size: 3rem !important;
}

div.jp-RenderedHTMLCommon h5 {
    font-size: 2.6rem !important;
}

div.jp-RenderedHTMLCommon h6 {
    font-size: 2.2rem !important;
    border-bottom: 1px solid rgb(204, 204, 204);
}

div.jp-RenderedHTMLCommon p,
div.jp-RenderedHTMLCommon pre,
div.jp-RenderedHTMLCommon code {
    font-size: 1em !important;
    color: var(--code-text-color)  /* REMOVED useless color forcing */;
}

/* Monospace Code - no code syntax highlight*/
div.jp-RenderedHTMLCommon pre {
    /* hack: using code background colour here to allow for compatibility */
    background-color: var(--code-background-color) !important;
    font-family: var(--txbk-content-mono-font-family) !important;
}

div.jp-RenderedHTMLCommon p {
    line-height: var(--txbk-content-line-height);
    text-align: justify !important;
}

div.jp-RenderedHTMLCommon p code {
    background-color: var(--txbk-content-mono-bgcolor) !important;
    font-size: var(--txbk-content-mono-font-size) !important;
}

div.jp-RenderedHTMLCommon p strong code {
    font-weight: bold !important;
}

div.jp-RenderedHTMLCommon p em code {
    font-style: italic !important;
}

div.jp-RenderedHTMLCommon pre code {

    /*--txbk-ui-mono-line-height: 1.3;*/

    font-size: 1em !important;
    padding: 1rem 1.5rem;
    display: block !important;
    color: var(--txkb-content-mono-color) !important;
    background-color: var(--txbk-content-mono-bgcolor) !important;
    font-family: var(--txbk-content-mono-font-family) !important;
    word-wrap: break-word;
    word-break: normal;
}

div.jp-RenderedHTMLCommon blockquote {
    --txbk-ui-color: #6f6f6f !important;

    margin: 2rem .2rem !important;
    padding: .3rem .5rem !important;
    border-left: .3rem solid #a7a7a7 !important;
}

div.jp-RenderedHTMLCommon blockquote p {
    padding: .2rem 1.5rem;
}

div.jp-RenderedHTMLCommon table {
    font-size: var(--txbk-content-font-size) !important;
    border-collapse: collapse;
    border-spacing: 0;
    overflow: auto;
    break-inside: auto;
    text-align: left;
    margin-top: 25px;
}

div.jp-RenderedHTMLCommon table thead {
    display: table-header-group;
    vertical-align: middle !important;
    border-bottom: none !important;
}

div.jp-RenderedHTMLCommon table thead tr,
div.jp-RenderedHTMLCommon table thead tr th,
div.jp-RenderedHTMLCommon table thead tr td,
div.jp-RenderedHTMLCommon table tbody tr,
div.jp-RenderedHTMLCommon table tbody tr th,
div.jp-RenderedHTMLCommon table tbody tr td {
    break-inside: avoid;
    break-after: auto;
    text-align: left !important;
    vertical-align: middle !important;
}

div.jp-RenderedHTMLCommon table tr th {
    border-bottom-width: 0;
}

div.jp-RenderedHTMLCommon ul,
div.jp-RenderedHTMLCommon ol {
    position: relative;
    display: block;
    margin-bottom: 0 !important;
    line-height: var(--txbk-content-line-height);
}

div.jp-RenderedHTMLCommon ul {
    list-style-type: disc;
}

div.jp-RenderedHTMLCommon ul li,
div.jp-RenderedHTMLCommon ol li {
    /*white-space: pre-wrap;*/
    padding: .8rem !important;
}

div.jp-RenderedHTMLCommon ul li > code,
div.jp-RenderedHTMLCommon ol li > code {
    font-size: .9em !important
}

div.jp-RenderedHTMLCommon ul li a code,
div.jp-RenderedHTMLCommon ol li a code {
    font-size: .9em !important
}

div.jp-RenderedHTMLCommon ul ul {
    list-style-type: circle !important;
}

div.jp-RenderedHTMLCommon ul ul,
div.jp-RenderedHTMLCommon ul ol,
div.jp-RenderedHTMLCommon ol ul,
div.jp-RenderedHTMLCommon ol ol {
    padding-top: .5rem !important;
}

div.jp-RenderedHTMLCommon ul li > ul li,
div.jp-RenderedHTMLCommon ul li > ol li,
div.jp-RenderedHTMLCommon ol li > ul li,
div.jp-RenderedHTMLCommon ol li > ol li {
    padding: .5rem !important;
}

div.jp-RenderedHTMLCommon ul li > ul li code,
div.jp-RenderedHTMLCommon ul li > ol li code,
div.jp-RenderedHTMLCommon ol li > ul li code,
div.jp-RenderedHTMLCommon ol li > ol li code {
    font-size: .9em !important;
}

div.jp-RenderedHTMLCommon ul li > ul li a code,
div.jp-RenderedHTMLCommon ul li > ol li a code,
div.jp-RenderedHTMLCommon ol li > ul li a code,
div.jp-RenderedHTMLCommon ol li > ol li a code {
    font-size: .9em !important;
    color: var(--link-color);
}

div.jp-RenderedHTMLCommon ul ul ul {
    list-style-type: square !important;
}

div.jp-RenderedHTMLCommon p > img:only-child {
    display: block;
    margin: auto;
    max-width: 70% !important;
}

div.jp-RenderedHTMLCommon img {
    max-width: 70%;
}

div.jp-InputPrompt{
    color: #aba9a9 !important;
    font-style: normal !important;
    font-size: 1.4rem;
    opacity: 1 !important;
}


div.jp-OutputPrompt {
    color: transparent !important;
}


/* Code export */

.cm-s-jupyter.CodeMirror {

    background: var(--code-background-color);
    color: var(--code-text-color);
}

/* Img MaxW classes */
div.jp-RenderedHTMLCommon img.maxw10,
div.jp-RenderedHTMLCommon p > img.maxw10 {
    max-width: 10% !important;
}

div.jp-RenderedHTMLCommon img.maxw15,
div.jp-RenderedHTMLCommon p > img.maxw15 {
    max-width: 15% !important;
}

div.jp-RenderedHTMLCommon img.maxw20,
div.jp-RenderedHTMLCommon p > img.maxw20 {
    max-width: 20% !important;
}

div.jp-RenderedHTMLCommon img.maxw25,
div.jp-RenderedHTMLCommon p > img.maxw25 {
    max-width: 25% !important;
}

div.jp-RenderedHTMLCommon img.maxw30,
div.jp-RenderedHTMLCommon p > img.maxw30 {
    max-width: 30% !important;
}

div.jp-RenderedHTMLCommon img.maxw40,
div.jp-RenderedHTMLCommon p > img.maxw40 {
    max-width: 40% !important;
}

div.jp-RenderedHTMLCommon img.maxw50,
div.jp-RenderedHTMLCommon p > img.maxw50 {
    max-width: 50% !important;
}

div.jp-RenderedHTMLCommon img.maxw80,
div.jp-RenderedHTMLCommon p > img.maxw80 {
    max-width: 80% !important;
}

div.jp-RenderedHTMLCommon img.maxw85,
div.jp-RenderedHTMLCommon p > img.maxw85 {
    max-width: 85% !important;
}

div.jp-RenderedHTMLCommon img.maxw90,
div.jp-RenderedHTMLCommon p > img.maxw90 {
    max-width: 90% !important;
}

div.jp-RenderedHTMLCommon img.maxw100,
div.jp-RenderedHTMLCommon p > img.maxw100 {
    max-width: 100% !important;
}

/*
Overlay with Shadow for Code Cell Selected !
*/
.jp-CodeCell.jp-mod-active.jp-mod-selected:not(.jp-mod-multiSelected) {
    border: none;
    background: transparent;
    box-shadow: 0 6px 18px #aaa;
    z-index: 10;
    top: -10px;
}

/* Standard Error */
.jp-RenderedText[data-mime-type='application/vnd.jupyter.stderr'] {
    background: none !important;
}


