/*
Author: Valerio Maggio < @leriomaggio >
Code: https://github.com/leriomaggio/notexbook-jupyter-theme
License: Apache License 2.0

 ======================================================

The color palette is inspired by the Crisp light theme
included in the Rainglow collection of VS Code Themes

Repo: https://github.com/rainglow/vscode/
*/

:root {
    /* Color Palette */
    --cl-lilac: #c6a7c6;
    --cl-black: #221a22;
    --cl-grey: #b8b8b8;
    --cl-white: #ffffff;
    --cl-yellow: #fc9a0f;
    --cl-dark-orange: #fc6a0f;
    --cl-purple: #765478;
    --cl-dark-purple: #4f3c4f;
    --cl-light-purple: #99769b;
    --cl-red: #cf433e;
    --cl-blue: #1565C0;


    /* Editor Theme */
    --cl-code-background-color: var(--cl-white);
    --cl-gutter-background: var(--cl-white);
    --cl-selection-background-color: var(--cl-yellow);
    --cl-line-numbers: var(--cl-grey);
    --cl-cursor: var(--cl-black);
    --cl-bracket: var(--cl-purple);
    --cl-matching-bracket: var(--cl-selection-background-color);
    --cl-code-text-color: var(--cl-black);
    --cl-keywords: var(--cl-purple);
    --cl-types: var(--cl-purple);
    --cl-variables: var(--cl-code-text-color);
    --cl-variables2: var(--cl-dark-purple);
    --cl-def: var(--cl-dark-orange);
    --cl-property: var(--cl-light-purple);
    --cl-meta: var(--cl-light-purple);
    --cl-builtin: var(--cl-dark-purple);
    --cl-attribute: var(--cl-code-text-color);
    --cl-strings: var(--cl-yellow);
    --cl-strings2: var(--cl-lilac);
    --cl-comments: var(--cl-lilac);
    --cl-operator: var(--cl-blue);
    --cl-numbers: var(--cl-dark-orange);
    /* Dataframe */
    --cl-dataframe: var(--cl-code-text-color);
    --cl-df-bg: var(--cl-white);
    --cl-df-thead: var(--cl-light-purple);
    --cl-df-thead-border: var(--cl-purple);
    --cl-df-tr-hover: var(--cl-selection-background-color);
    --cl-df-border: var(--cl-white);
    --cl-df-border-right: var(--cl-grey);
    --cl-df-th-bg: var(--cl-white);
}